#$Id$#

class Api:
     """This class is used to maintain the service URL."""
     
     def __init__(self):
         """Initialize parameters for API class."""
 
         self.base_url = 'https://books.zoho.in/api/v3/'

    
     
