from setuptools import setup

setup(
    name='zohobooks-api',
    version='1.1',
    packages=['books', 'books.api', 'books.util', 'books.model', 'books.parser', 'books.service', 'books.exception'],
    url='',
    license='MIT',
    author='Sagar',
    author_email='sagarnrng17@gmail.com',
    description='Zoho Books Python Client Library'
)
